Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(319)

Unified Diff: chrome/browser/storage_monitor/test_storage_monitor_win.h

Issue 12382005: Rename RemovableDeviceNotifications=>StorageMonitor (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 7 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/storage_monitor/test_storage_monitor_win.h
diff --git a/chrome/browser/storage_monitor/test_removable_device_notifications_window_win.h b/chrome/browser/storage_monitor/test_storage_monitor_win.h
similarity index 45%
rename from chrome/browser/storage_monitor/test_removable_device_notifications_window_win.h
rename to chrome/browser/storage_monitor/test_storage_monitor_win.h
index 314ab07648a827306ad7e5f3c7b5a8847ec378ef..bb29d9f4df8adc9de1641bcf4db9552c395826f0 100644
--- a/chrome/browser/storage_monitor/test_removable_device_notifications_window_win.h
+++ b/chrome/browser/storage_monitor/test_storage_monitor_win.h
@@ -2,16 +2,16 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
//
// This file contains a subclass of RemovableDeviceNotificationsWindowWin to
// simulate device changed events for testing.
#ifndef CHROME_BROWSER_STORAGE_MONITOR_TEST_REMOVABLE_DEVICE_NOTIFICATIONS_WINDOW_WIN_H_
#define CHROME_BROWSER_STORAGE_MONITOR_TEST_REMOVABLE_DEVICE_NOTIFICATIONS_WINDOW_WIN_H_
#include <windows.h>
#include "base/memory/ref_counted.h"
-#include "chrome/browser/storage_monitor/removable_device_notifications_window_win.h"
+#include "chrome/browser/storage_monitor/storage_monitor_win.h"
namespace chrome {
namespace test {
@@ -19,24 +19,23 @@ namespace test {
class TestPortableDeviceWatcherWin;
class TestVolumeMountWatcherWin;
-class TestRemovableDeviceNotificationsWindowWin
- : public RemovableDeviceNotificationsWindowWin {
+class TestStorageMonitorWin: public StorageMonitorWin {
public:
- TestRemovableDeviceNotificationsWindowWin(
+ TestStorageMonitorWin(
TestVolumeMountWatcherWin* volume_mount_watcher,
TestPortableDeviceWatcherWin* portable_device_watcher);
- virtual ~TestRemovableDeviceNotificationsWindowWin();
+ virtual ~TestStorageMonitorWin();
void InjectDeviceChange(UINT event_type, DWORD data);
VolumeMountWatcherWin* volume_mount_watcher();
private:
- DISALLOW_COPY_AND_ASSIGN(TestRemovableDeviceNotificationsWindowWin);
+ DISALLOW_COPY_AND_ASSIGN(TestStorageMonitorWin);
};
} // namespace test
} // namespace chrome
-#endif // CHROME_BROWSER_STORAGE_MONITOR_TEST_REMOVABLE_DEVICE_NOTIFICATIONS_WINDOW_WIN_H_
+#endif // CHROME_BROWSER_STORAGE_MONITOR_TEST_STORAGE_MONITOR_WIN_H_

Powered by Google App Engine
This is Rietveld 408576698
@@ -2,16 +2,16 @@
// found in the LICENSE file.
//
-// This file contains a subclass of RemovableDeviceNotificationsWindowWin to
-// simulate device changed events for testing.
+// This file contains a subclass of StorageMonitorWin to simulate device
+// changed events for testing.
-#ifndef CHROME_BROWSER_STORAGE_MONITOR_TEST_REMOVABLE_DEVICE_NOTIFICATIONS_WINDOW_WIN_H_
-#define CHROME_BROWSER_STORAGE_MONITOR_TEST_REMOVABLE_DEVICE_NOTIFICATIONS_WINDOW_WIN_H_
+#ifndef CHROME_BROWSER_STORAGE_MONITOR_TEST_STORAGE_MONITOR_WIN_H_
+#define CHROME_BROWSER_STORAGE_MONITOR_TEST_STORAGE_MONITOR_WIN_H_
#include <windows.h>
#include "base/memory/ref_counted.h"